;;; GNU Guix --- Functional package management for GNU
;;; Copyright © 2023 Adrien 'neox' Bourmault <neox@gnu.org>
;;;
;;; This file is part of GNU Guix.
;;;
;;; GNU Guix is free software; you can redistribute it and/or modify it
;;; under the terms of the GNU General Public License as published by
;;; the Free Software Foundation; either version 3 of the License, or (at
;;; your option) any later version.
;;;
;;; GNU Guix is distributed in the hope that it will be useful, but
;;; WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
;;; along with GNU Guix.  If not, see <http://www.gnu.org/licenses/>.

(define-module (xmlcopyeditor)
  #:use-module ((guix licenses)
                #:select (gpl3+ lgpl2.0+ lgpl3+ public-domain))
  #:use-module (gnu packages)
  #:use-module (gnu packages aspell)
  #:use-module (gnu packages boost)
  #:use-module (gnu packages glib)
  #:use-module (gnu packages pkg-config)
  #:use-module (gnu packages pcre)
  #:use-module (gnu packages wxwidgets)
  #:use-module (gnu packages xml)
  #:use-module (guix i18n)
  #:use-module (guix utils)
  #:use-module (guix gexp)
  #:use-module (guix packages)
  #:use-module (guix download)
  #:use-module (guix git-download)
  #:use-module (guix build-system gnu)
  #:use-module (guix build-system trivial)
  #:use-module ((guix licenses) #:prefix license:))

(define-public xmlcopyeditor
  (package
    (name "xmlcopyeditor")
    (version "1.3.1.1")
    (source
     (origin
       (method git-fetch)
       (uri
        (git-reference
         (url "https://forge.chalec.org/neox/xml-copy-editor-code.git")
         (commit version)))
       (file-name
        (git-file-name name version))
       (sha256
        (base32 "05fryg98knxlqsjgx3wwj6pqkw5nz6q5wgjcql8xdfxc2ggbcyb5"))))
    (build-system gnu-build-system)
    (arguments
     (list
      #:tests? #f
      #:configure-flags
      #~(list 
          (string-append 
            "--prefix=" #$output)
          (string-append
            "--exec-prefix=" #$output))))
    (native-inputs
      (list
        intltool
        pkg-config))
    (inputs
      (list 
        pcre2
        wxwidgets
        aspell
        boost
        xerces-c
        libxml2
        libxslt
        expat))
    (synopsis "XML Copy Editor")
    (description
     "Fast, free, validating XML editor.")
    (home-page "https://xml-copy-editor.sourceforge.io/")
    (license gpl3+)))
